Crate ark

Crate ark 

Re-exports

pub extern crate bitcoin;

Re-exports

pub use crate::address::Address;
pub use crate::encode::ProtocolEncoding;
pub use crate::encode::WriteExt;
pub use crate::encode::ReadExt;
pub use crate::encode::ProtocolDecodingError;
pub use crate::vtxo::Vtxo;
pub use crate::vtxo::VtxoId;
pub use crate::vtxo::VtxoPolicy;
pub use crate::vtxo::ServerVtxoPolicy;
pub use crate::vtxo::ServerVtxo;

Modules

address
arkoor
Utilities to create out-of-round transactions using checkpoint transactions.
attestations
board
Board flow:
connectors
encode
Definitions of protocol encodings.
error
fees
forfeit
integration
lightning
mailbox
Types for using the Unified Mailbox feature of the bark server.
message
Signing and verification of arbitrary messages.
musig
offboard
Offboard mechanism using connector-swaps
rounds
scripts
tree
util
vtxo
Representations of VTXOs in an Ark.

Structs

ArkInfo
SECP
Global secp context.
SignedVtxoRequest
Request for the creation of an vtxo in a signed round
VtxoRequest
Request for the creation of an vtxo.