pub struct LightningReceiveAttestation { /* private fields */ }Expand description
Attestation for proving ownership of a VTXO when claiming a Lightning receive.
This attestation commits to a payment hash and the input VTXO ID to create a unique signature proving the user controls the input VTXO and is authorised as a mitigation against liquidity denial-of-service attacks.
Implementations
Sourceimpl LightningReceiveAttestation
impl LightningReceiveAttestation
Sourcepub fn new(
payment_hash: PaymentHash,
vtxo_id: VtxoId,
vtxo_keypair: &Keypair,
) -> Self
pub fn new( payment_hash: PaymentHash, vtxo_id: VtxoId, vtxo_keypair: &Keypair, ) -> Self
Create a new attestation by signing with the provided keypair