RoundAttemptAttestation

Struct RoundAttemptAttestation 

pub struct RoundAttemptAttestation { /* private fields */ }
Attestation for self-signed round participation

Contains a signature proving ownership of a VTXO for participation in a specific round attempt with a given challenge.

Implementations

Source

impl RoundAttemptAttestation

pub fn new( challenge: Challenge, vtxo_id: VtxoId, vtxo_reqs: &[SignedVtxoRequest], vtxo_keypair: &Keypair, ) -> Self

Create a new attestation by signing with the provided keypair

pub fn signature(&self) -> &Signature

Get the signature

pub fn verify( &self, challenge: Challenge, vtxo: &Vtxo, vtxo_reqs: &[SignedVtxoRequest], ) -> Result<(), Error>

Verify the attestation against a VTXO