pub struct VtxoStatusAttestation { /* private fields */ }Expand description
Attestation for proving ownership of a VTXO when querying its status.
This is the simplest attestation - it only commits to the VTXO ID itself, with no additional challenge data or context. It proves the user controls the VTXO and is authorised to query its status.
No additional unique or random challenge data is necessary here. We’re not concerned with guarding against “replay” attacks as this attestation is for informational purposes and knowledge of this proof by a third party would indicate some kind of prior privacy leak for the user.
A malicious third party that can access this signed message would only be able to query the status of this specific VTXO.
Implementations