Module encode

Module encode 

Definitions of protocol encodings.

Modules

serde
Module that helps to encode ProtocolEncoding objects with serde.

Structs

LengthPrefixedVector
A wrapper around a Vec<T> for any T with ProtocolEncoding that can be safely encoded and decoded using a CompactSize length prefix
OversizedVectorError

Enums

ProtocolDecodingError
Error occuring during protocol decoding.

Constants

MAX_SCRIPT_PUBKEY_SIZE
Maximum allowed scriptPubkey size in vbytes
MAX_VEC_SIZE
Maximum size, in bytes, of a vector we are allowed to decode

Traits

ProtocolEncoding
Trait for encoding objects according to the bark protocol encoding.
ReadExt
Utility trait to read some primitive values into our encoding format.
WriteExt
Utility trait to write some primitive values into our encoding format.