Module fees

Module fees 

Structs

BoardFees
Fees for boarding the ark.
FeeSchedule
Complete fee schedule for all operations.
LightningReceiveFees
Fees for lightning receive operations.
LightningSendFees
Fees for lightning send operations.
OffboardFees
Fees for offboarding from the ark.
PpmExpiryFeeEntry
Entry in a table to calculate the PPM (parts per million) fee rate of a transaction based on how new a VTXO is.
PpmFee
A fee with sub-satoshi precision: the undivided numerator of a ppm fee calculation, in millionths of a satoshi.
PpmFeeRate
RefreshFees
Fees for refresh operations.
VtxoFeeInfo
A very basic struct to hold information for use in calculating the fees of transactions.

Enums

FeeScheduleValidationError
Error types for fee schedule validation.
FeeValidationError
Error types for fee validation.

Functions

calc_ppm_expiry_fee
Calculates the total fee based on the provided fee-chargeable amount, a table of PPM (Parts Per Million) expiry-based fee rates, and an iterable list of VTXO information.
calc_ppm_expiry_fee_legacyDeprecated
calc_ppm_expiry_fee as calculated by clients on protocol versions that apply the fee rate to each VTXO separately rather than to the total.
validate_and_subtract_fee
Validates fee amounts and calculates the resulting amount after fee.
validate_and_subtract_fee_min_dust
Validates fee amounts and calculates the resulting amount after fee.