pub struct BoardFees {
pub min_fee: Amount,
pub base_fee: Amount,
pub ppm: PpmFeeRate,
}Expand description
Fees for boarding the ark.
Fields
min_fee: AmountMinimum fee to charge.
base_fee: AmountA fee applied to every transaction regardless of value.
ppm: PpmFeeRatePPM (parts per million) fee rate to apply based on the value of the transaction.
Implementations
Sourceimpl BoardFees
impl BoardFees
Sourcepub fn calculate(&self, amount: Amount) -> Option<Amount>
pub fn calculate(&self, amount: Amount) -> Option<Amount>
Calculate the total fee for a board operation.
Returns the maximum of the calculated fee (base_fee + ppm) and the minimum fee. None if an
overflow occurs.
Sourcepub fn calculate_legacy(&self, amount: Amount) -> Option<Amount>
👎Deprecated: only for protocol versions <= 3
pub fn calculate_legacy(&self, amount: Amount) -> Option<Amount>
only for protocol versions <= 3
BoardFees::calculate for clients on protocol versions that round the ppm fee down.