PpmExpiryFeeEntry

Struct PpmExpiryFeeEntry 

pub struct PpmExpiryFeeEntry {
    pub expiry_blocks_threshold: u32,
    pub ppm: PpmFeeRate,
}
Entry in a table to calculate the PPM (parts per million) fee rate of a transaction based on how new a VTXO is.

Fields

expiry_blocks_threshold: u32

A threshold for the number of blocks until a VTXO expires for the ppm amount to apply. As an example, if this value is set to 50 and a VTXO expires in 60 blocks, this PpmExpiryFeeEntry will be used to calculate the fee unless another entry exists with an expiry_blocks_threshold with a value between 51 and 60 (inclusive).

ppm: PpmFeeRate

PPM (parts per million) fee rate to apply for this expiry period.