pub struct RefreshFees {
pub base_fee: Amount,
pub ppm_expiry_table: Vec<PpmExpiryFeeEntry>,
}Expand description
Fees for refresh operations.
Fields
base_fee: AmountA fee applied to every transaction regardless of value.
ppm_expiry_table: Vec<PpmExpiryFeeEntry>A table mapping how soon a VTXO will expire to a PPM (parts per million) fee rate.
The table should be sorted by each expiry_blocks_threshold value in ascending order.
Implementations
Sourceimpl RefreshFees
impl RefreshFees
Sourcepub fn calculate(
&self,
vtxos: impl IntoIterator<Item = VtxoFeeInfo>,
) -> Option<Amount>
pub fn calculate( &self, vtxos: impl IntoIterator<Item = VtxoFeeInfo>, ) -> Option<Amount>
Calculate the total fee for a refresh operation.
Returns None if an overflow occurs.
Sourcepub fn calculate_no_base_fee(
&self,
vtxos: impl IntoIterator<Item = VtxoFeeInfo>,
) -> Option<Amount>
pub fn calculate_no_base_fee( &self, vtxos: impl IntoIterator<Item = VtxoFeeInfo>, ) -> Option<Amount>
Calculate the fee for a refresh operation, excluding the base fee.
Returns None if an overflow occurs.