pub struct VtxoFeeInfo {
pub amount: Amount,
pub expiry_blocks: u32,
}Expand description
A very basic struct to hold information for use in calculating the fees of transactions.
Fields
amount: AmountThe total amount of the VTXO.
expiry_blocks: u32Number of blocks until expiry.
Implementations
Sourceimpl VtxoFeeInfo
impl VtxoFeeInfo
Sourcepub fn from_vtxo_and_tip<G>(vtxo: &Vtxo<G>, tip: BlockHeight) -> Self
pub fn from_vtxo_and_tip<G>(vtxo: &Vtxo<G>, tip: BlockHeight) -> Self
Constructs a VtxoFeeInfo instance from the given Vtxo and tip BlockHeight