Module forfeit

Module forfeit 

Structs

HashLockedForfeitBundle
A bundle of a signature and metadata that forfeits a user’s VTXO conditional on the server revealing a secret preimage

Functions

connector_forfeit_sighash_connector
The sighash of the connector input of a forfeit tx.
connector_forfeit_sighash_exit
The sighash of the exit tx input of a forfeit tx.
create_connector_forfeit_tx
create_hark_forfeit_tx
Construct the forfeit tx in the hArk forfeit protocol
hark_forfeit_claim_taproot
The taproot for the policy of the output of the hArk forfeit tx