pub enum Invoice {
Bolt11(Bolt11Invoice),
Bolt12(Bolt12Invoice),
}Expand description
Enum to represent either a lightning Bolt11Invoice or a Bolt12Invoice.
Variants
Bolt11(Bolt11Invoice)
Bolt12(Bolt12Invoice)
Implementations
Sourceimpl Invoice
impl Invoice
pub fn into_bolt11(self) -> Option<Bolt11Invoice>
pub fn payment_hash(&self) -> PaymentHash
pub fn network(&self) -> Network
Sourcepub fn get_final_amount(
&self,
user_amount: Option<Amount>,
) -> Result<Amount, CheckAmountError>
pub fn get_final_amount( &self, user_amount: Option<Amount>, ) -> Result<Amount, CheckAmountError>
Get the amount to be paid. It checks both user and invoice equality if both are provided, else it tries to return one of them, or returns an error if neither are provided.
pub fn amount_msat(&self) -> Option<u64>
pub fn check_signature(&self) -> Result<(), CheckSignatureError>