OfferAmount

Enum OfferAmount 

pub enum OfferAmount {
    Bitcoin {
        amount_msats: u64,
    },
    Currency {
        iso4217_code: CurrencyCode,
        amount: u64,
    },
}
The minimum amount required for an item in an Offer, denominated in either bitcoin or another currency.

Variants



Bitcoin

An amount of bitcoin.

Fields

amount_msats: u64

The amount in millisatoshi.



Currency

An amount of currency specified using ISO 4217.

Fields

iso4217_code: CurrencyCode

The currency that the amount is denominated in.

amount: u64

The amount in the currency unit adjusted by the ISO 4217 exponent (e.g., USD cents).