offer_request_amount

Function offer_request_amount 

pub fn offer_request_amount(
    offer: &Offer,
    user_amount: Option<Amount>,
) -> Result<Amount, CheckAmountError>
The amount to request when fetching an invoice for offer: the amount the user asked to pay, or, when they didn’t ask for a specific one, the offer’s own amount.