Module mailbox

Module mailbox 

Types for using the Unified Mailbox feature of the bark server.

For more information on the mailbox, check the docs/mailbox.md file.

Structs

BlindedMailboxIdentifier
Blinded identifier for a mailbox
InvalidMailboxIdentifier
MailboxAuthorization
Authorization to read a VTXO mailbox
MailboxBlindingError
The blinded mailbox point and the ECDH tweak sum to the point at infinity, which is not a valid curve point. This happens when the peer chose the blinded point equal to the ECDH-derived tweak, so treat it as an invalid peer input.
MailboxIdentifier
Identifier for a mailbox

Enums

MailboxType