pub fn sign(keypair: &Keypair, message: &[u8]) -> SignatureExpand description
Sign an arbitrary message with the given keypair
The message is domain-separated by hashing it with a constant prefix, see the module documentation for the exact scheme.
pub fn sign(keypair: &Keypair, message: &[u8]) -> SignatureSign an arbitrary message with the given keypair
The message is domain-separated by hashing it with a constant prefix, see the module documentation for the exact scheme.