AggregatedNonce

Struct AggregatedNonce 

pub struct AggregatedNonce(/* private fields */);
Musig aggregated nonce computed by aggregating all individual public nonces

Implementations

Source

impl AggregatedNonce

pub fn new(nonces: &[&PublicNonce]) -> AggregatedNonce

Combines received PublicNonces into a single AggregatedNonce.

This is useful to reduce the communication between signers, because instead of everyone sending nonces to everyone else, there can be one party receiving all nonces, combining the nonces with this function and then sending only the combined nonce back to the signers.

Examples

// The counter must never repeat for a given keypair.
// Read documentation for more details.

let msg = b"Public message we want to sign!!";

let keypair1 = Keypair::from_secret_key(&sk1);
let (_sec_nonce1, pub_nonce1) = key_agg_cache.nonce_gen(0, &keypair1, msg, None);

// Signer two does the same: Possibly on a different device
let keypair2 = Keypair::from_secret_key(&sk2);
let (_sec_nonce2, pub_nonce2) = key_agg_cache.nonce_gen(0, &keypair2, msg, None);

let aggnonce = AggregatedNonce::new(&[&pub_nonce1, &pub_nonce2]);
Panics

Panics if an empty slice of nonces is provided.

pub fn serialize(&self) -> [u8; 66]

Serializes an AggregatedNonce into a 66 byte array.

pub fn from_byte_array(data: &[u8; 66]) -> Result<AggregatedNonce, ParseError>

Deserializes an AggregatedNonce from a byte array.

Errors
pub fn as_ptr(&self) -> *const MusigAggNonce

Gets a const pointer to the inner AggregatedNonce.

pub fn as_mut_ptr(&mut self) -> *mut MusigAggNonce

Gets a mut pointer to the inner AggregatedNonce.