SessionSecretRand

Struct SessionSecretRand 

pub struct SessionSecretRand(/* private fields */);
Session Id for a MuSig session.

Implementations

Source

impl SessionSecretRand

pub fn assume_unique_per_nonce_gen(inner: [u8; 32]) -> SessionSecretRand

Creates a new SessionSecretRand with the given bytes.

Special care must be taken that the bytes are unique for each call to KeyAggCache::nonce_gen or new_nonce_pair. The simplest recommendation is to use a cryptographicaly random 32-byte value.

If the rand feature is enabled, [SessionSecretRand::from_rng] can be used to generate a random session id.

Panics

Panics if passed the all-zeros string. This is disallowed by the upstream library. The input to this function should either be the whitened output of a random number generator, or if that is not available, the output of a stable monotonic counter.

pub fn to_byte_array(&self) -> [u8; 32]

Obtains the inner bytes of the SessionSecretRand.

pub fn as_byte_array(&self) -> &[u8; 32]

Obtains a reference to the inner bytes of the SessionSecretRand.