Module offboard

Module offboard 

Offboard mechanism using connector-swaps

Connector VTXOs

We create internal “ServerVtxo“s for the connector outputs. Because they must not be swept before they are no longer required (i.e. when the input VTXO expires), we use the expiry height on the VTXO to indicate when they can be swept.

Structs

InvalidOffboardRequestError
InvalidOffboardTxError
InvalidUserPartialSignatureError
OffboardForfeitContext
OffboardForfeitResult
OffboardForfeitSignatures
OffboardRequest
Contains information regarding an offboard that a client would like to perform.

Constants

OFFBOARD_TX_CONNECTOR_VOUT
The output index of the connector output in the offboard tx
OFFBOARD_TX_OFFBOARD_VOUT
The output index of the offboard output in the offboard tx