ArkInfo

Struct ArkInfo 

pub struct ArkInfo {
Show 17 fields pub network: Network, pub server_pubkey: PublicKey, pub mailbox_pubkey: PublicKey, pub round_interval: Duration, pub nb_round_nonces: usize, pub vtxo_exit_delta: BlockDelta, pub vtxo_expiry_delta: BlockDelta, pub htlc_send_expiry_delta: BlockDelta, pub htlc_expiry_delta: BlockDelta, pub max_vtxo_amount: Option<Amount>, pub required_board_confirmations: usize, pub max_user_invoice_cltv_delta: u16, pub min_board_amount: Amount, pub offboard_feerate: FeeRate, pub ln_receive_anti_dos_required: bool, pub fees: FeeSchedule, pub max_vtxo_exit_depth: u16,
}

Fields

network: Network

The bitcoin network the server operates on

server_pubkey: PublicKey

The Ark server pubkey

mailbox_pubkey: PublicKey

The pubkey used for blinding unified mailbox IDs

round_interval: Duration

The interval between each round

nb_round_nonces: usize

Number of nonces per round

vtxo_exit_delta: BlockDelta

Delta between exit confirmation and coins becoming spendable

vtxo_expiry_delta: BlockDelta

Expiration delta of the VTXO

htlc_send_expiry_delta: BlockDelta

The number of blocks after which an HTLC-send VTXO expires once granted.

htlc_expiry_delta: BlockDelta

The number of blocks to keep between Lightning and Ark HTLCs expiries

max_vtxo_amount: Option<Amount>

Maximum amount of a VTXO

required_board_confirmations: usize

The number of confirmations required to register a board vtxo

max_user_invoice_cltv_delta: u16

Maximum CLTV delta server will allow clients to request an invoice generation with.

min_board_amount: Amount

Minimum amount for a board the server will cosign

offboard_feerate: FeeRate
👎Deprecated since 0.1.5:

use ServerConnection::offboard_feerate instead

The feerate for offboard transactions.

Deprecated in favour of the dedicated GetOffboardFeeRate RPC. This field is still populated for backwards compatibility with older clients but may be stale; prefer [ServerConnection::offboard_feerate] which calls the dedicated endpoint.

ln_receive_anti_dos_required: bool

Indicates whether the Ark server requires clients to either provide a VTXO ownership proof, or a lightning receive token when preparing a lightning claim.

fees: FeeSchedule

Fee schedule for all Ark operations

max_vtxo_exit_depth: u16

Maximum exit depth (genesis chain length) allowed for a VTXO. Once a VTXO’s exit depth reaches this value the server will refuse to cosign further OOR transactions spending it. Clients should refresh their VTXOs into a round before this limit is reached.