Module signed

Module signed 

Modules

builder
This module allows a single party to construct his own signed VTXO tree, to then request signatures from the server.

Structs

CachedSignedVtxoTree
A fully signed VTXO tree, with all the transaction cached.
HashlockVersionDetectError
The hashlock version of a tree couldn’t be determined because its cosign signatures don’t verify for any version. This means the tree is corrupt.
LeafVtxoCosignContext
LeafVtxoCosignRequest
LeafVtxoCosignResponse
NotHarkLeafError
The VTXO can’t take part in the hArk leaf cosign flow because its last genesis transition is not hash-locked.
SignedVtxoTreeSpec
All the information needed to uniquely specify a fully signed VTXO tree.
UnsignedVtxoTree
A VTXO tree ready to be signed.
VtxoLeafSpec
VtxoTreeSpec
All the information that uniquely specifies a VTXO tree before it has been signed.

Enums

CosignSignatureError
Error returned from cosigning a VTXO tree.
HashlockVersion
The version of the hashlock clauses used in the leaves of a VTXO tree.

Constants

NODE_SPEND_WEIGHT
The upper bound witness weight to spend a node transaction.

Functions

cosign_taproot
The taproot spend info of an output that is spent by an internal node tx
expiry_clause
The expiry clause hidden in the node taproot as only script.
hashlocked_leaf_sighash
Calculate the scriptspend sighash of a hArk leaf transaction
hashlocked_leaf_sighash_v0
Calculate the scriptspend sighash of a hArk leaf transaction
leaf_cosign_taproot
The taproot of the leaf policy, i.e. of the output that is spent by the leaf tx
leaf_cosign_taproot_v0
The taproot of the leaf policy, i.e. of the output that is spent by the leaf tx
unlock_clause
The hash-based unlock clause that requires a signature and a preimage
unlock_clause_v0
The hash-based unlock clause that requires a signature and a preimage

Type Aliases

UnlockHash
Hash to lock hArk VTXOs from users before forfeits
UnlockPreimage
Preimage to unlock hArk VTXOs