pub struct HashDelaySignClause {
pub pubkey: PublicKey,
pub hash: Hash,
pub block_delta: BlockDelta,
}Expand description
A clause that allows to sign and spend the UTXO after a relative timelock, if preimage matching the hash is provided.
Fields
pubkey: PublicKeyhash: Hashblock_delta: BlockDeltaImplementations
Sourceimpl HashDelaySignClause
impl HashDelaySignClause
Sourcepub fn extract_preimage_from_witness(
witness: &Witness,
payment_hash: PaymentHash,
) -> Option<Preimage>
pub fn extract_preimage_from_witness( witness: &Witness, payment_hash: PaymentHash, ) -> Option<Preimage>
Try to extract the preimage from a witness that spends this clause.
Witness layout: [signature, preimage, tapscript, control_block].
Returns the preimage if it is 32 bytes and hashes to the given payment hash.