pub struct HashSignClause_v0 {
pub pubkey: PublicKey,
pub hash: Hash,
}Expand description
A clause that allows spending by revealing a preimage and providing a signature.
This is used for the unlock clause in hArk leaf outputs, where the aggregate pubkey of user+server must sign, and a preimage must be revealed.
Fields
pubkey: PublicKeyhash: HashTrait Implementations
Sourceimpl Clone for HashSignClause_v0
impl Clone for HashSignClause_v0
Sourcefn clone(&self) -> HashSignClause_v0
fn clone(&self) -> HashSignClause_v0
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HashSignClause_v0
impl Debug for HashSignClause_v0
Sourceimpl Into<VtxoClause> for HashSignClause_v0
impl Into<VtxoClause> for HashSignClause_v0
Sourcefn into(self) -> VtxoClause
fn into(self) -> VtxoClause
Converts this type into the (usually inferred) input type.
Sourceimpl TapScriptClause for HashSignClause_v0
impl TapScriptClause for HashSignClause_v0
Sourcetype WitnessData = (Signature, [u8; 32])
type WitnessData = (Signature, [u8; 32])
The type of witness data required to sign the clause.
Sourcefn witness(
&self,
data: &Self::WitnessData,
control_block: &ControlBlock,
) -> Witness
fn witness( &self, data: &Self::WitnessData, control_block: &ControlBlock, ) -> Witness
Constructs the witness for the clause.
Sourcefn witness_size<G, P: Policy>(&self, vtxo: &Vtxo<G, P>) -> usize
fn witness_size<G, P: Policy>(&self, vtxo: &Vtxo<G, P>) -> usize
Computes the total witness size in bytes for spending via this clause. Read more
Sourcefn control_block<G, P: Policy>(&self, vtxo: &Vtxo<G, P>) -> ControlBlock
fn control_block<G, P: Policy>(&self, vtxo: &Vtxo<G, P>) -> ControlBlock
Construct the taproot control block for spending the VTXO using this clause