Definitions of protocol encodings.
Modules
- serde
- Module that helps to encode ProtocolEncoding objects with serde.
Structs
- Length
Prefixed Vector - A wrapper around a
Vec<T>for anyTwith ProtocolEncoding that can be safely encoded and decoded using a CompactSize length prefix - Oversized
Vector Error
Enums
- Protocol
Decoding Error - Error occuring during protocol decoding.
Constants
- MAX_
SCRIPT_ PUBKEY_ SIZE - Maximum allowed scriptPubkey size in vbytes
- MAX_
VEC_ SIZE - Maximum size, in bytes, of a vector we are allowed to decode
Traits
- Protocol
Encoding - Trait for encoding objects according to the bark protocol encoding.
- ReadExt
- Utility trait to read some primitive values into our encoding format.
- Write
Ext - Utility trait to write some primitive values into our encoding format.