Module fees

Module fees 

Structs

BoardFees
Fees for boarding the ark.
FeeSchedule
Complete fee schedule for all operations.
LightningReceiveFees
Fees for lightning receive operations.
LightningSendFees
Fees for lightning send operations.
OffboardFees
Fees for offboarding from the ark.
PpmExpiryFeeEntry
Entry in a table to calculate the PPM (parts per million) fee rate of a transaction based on how new a VTXO is.
PpmFeeRate
RefreshFees
Fees for refresh operations.
VtxoFeeInfo
A very basic struct to hold information for use in calculating the fees of transactions.

Enums

FeeScheduleValidationError
Error types for fee schedule validation.
FeeValidationError
Error types for fee validation.

Functions

calc_ppm_expiry_fee
Calculates the total fee based on the provided fee-chargeable amount, a table of PPM (Parts Per Million) expiry-based fee rates, and an iterable list of VTXO information.
validate_and_subtract_fee
Validates fee amounts and calculates the resulting amount after fee.
validate_and_subtract_fee_min_dust
Validates fee amounts and calculates the resulting amount after fee.