BoardFees

Struct BoardFees 

pub struct BoardFees {
    pub min_fee: Amount,
    pub base_fee: Amount,
    pub ppm: PpmFeeRate,
}
Fees for boarding the ark.

Fields

min_fee: Amount

Minimum fee to charge.

base_fee: Amount

A fee applied to every transaction regardless of value.

ppm: PpmFeeRate

PPM (parts per million) fee rate to apply based on the value of the transaction.

Implementations

Source

impl BoardFees

pub fn calculate(&self, amount: Amount) -> Option<Amount>

Calculate the total fee for a board operation. Returns the maximum of the calculated fee (base_fee + ppm) and the minimum fee. None if an overflow occurs.