pub struct BoardFees {
pub min_fee: Amount,
pub base_fee: Amount,
pub ppm: PpmFeeRate,
}Expand description
Fees for boarding the ark.
Fields
min_fee: AmountMinimum fee to charge.
base_fee: AmountA fee applied to every transaction regardless of value.
ppm: PpmFeeRatePPM (parts per million) fee rate to apply based on the value of the transaction.
Implementations