pub struct LightningSendFees {
pub min_fee: Amount,
pub base_fee: Amount,
pub ppm_expiry_table: Vec<PpmExpiryFeeEntry>,
}Expand description
Fees for lightning send operations.
Fields
min_fee: AmountMinimum fee to charge.
base_fee: AmountA fee applied to every transaction regardless of value.
ppm_expiry_table: Vec<PpmExpiryFeeEntry>A table mapping how soon a VTXO will expire to a PPM (parts per million) fee rate.
The table should be sorted by each expiry_blocks_threshold value in ascending order.
Implementations
Sourceimpl LightningSendFees
impl LightningSendFees
Sourcepub fn calculate(
&self,
amount: Amount,
vtxos: impl IntoIterator<Item = VtxoFeeInfo>,
) -> Option<Amount>
pub fn calculate( &self, amount: Amount, vtxos: impl IntoIterator<Item = VtxoFeeInfo>, ) -> Option<Amount>
Calculate the total fee for a lightning send operation.
Returns None if an overflow occurs.