pub struct OffboardFees {
pub base_fee: Amount,
pub fixed_additional_vb: u64,
pub ppm_expiry_table: Vec<PpmExpiryFeeEntry>,
}Expand description
Fees for offboarding from the ark.
Fields
base_fee: AmountA fee applied to every transaction regardless of value.
fixed_additional_vb: u64Fixed number of virtual bytes charged offboard on top of the output size.
The fee for an offboard will be this value, plus the offboard output virtual size,
multiplied with the offboard fee rate, plus the base_fee, and plus the additional fee
calculated with the ppm_expiry_table.
ppm_expiry_table: Vec<PpmExpiryFeeEntry>A table mapping how soon a VTXO will expire to a PPM (parts per million) fee rate.
The table should be sorted by each expiry_blocks_threshold value in ascending order.
Implementations
Sourceimpl OffboardFees
impl OffboardFees
Sourcepub fn calculate(
&self,
destination: &ScriptBuf,
amount: Amount,
fee_rate: FeeRate,
vtxos: impl IntoIterator<Item = VtxoFeeInfo>,
) -> Option<Amount>
pub fn calculate( &self, destination: &ScriptBuf, amount: Amount, fee_rate: FeeRate, vtxos: impl IntoIterator<Item = VtxoFeeInfo>, ) -> Option<Amount>
Returns the fee charged for the user to make an offboard given the fee rate.
Returns None in the calculation overflows because of insane destinations or fee rates.