pub struct HashLockedForfeitBundle {
pub vtxo_id: VtxoId,
pub unlock_hash: UnlockHash,
pub user_nonce: PublicNonce,
pub part_sig: PartialSignature,
}Expand description
A bundle of a signature and metadata that forfeits a user’s VTXO conditional on the server revealing a secret preimage
Fields
vtxo_id: VtxoIdunlock_hash: UnlockHashuser_nonce: PublicNoncepart_sig: PartialSignatureUser’s partial signature on the forfeit tx
Implementations
Sourceimpl HashLockedForfeitBundle
impl HashLockedForfeitBundle
Sourcepub fn new<G>(
vtxo: &Vtxo<G>,
unlock_hash: UnlockHash,
user_key: &Keypair,
server_nonce: &PublicNonce,
) -> Self
pub fn new<G>( vtxo: &Vtxo<G>, unlock_hash: UnlockHash, user_key: &Keypair, server_nonce: &PublicNonce, ) -> Self
Create a new HashLockedForfeitBundle for the given VTXO
This is used to forfeit the VTXO to the server conditional on receiving the unlock preimage corresponding to the given unlock hash.
Sourcepub fn verify<G>(
&self,
vtxo: &Vtxo<G>,
server_nonce: &PublicNonce,
) -> Result<(), &'static str>
pub fn verify<G>( &self, vtxo: &Vtxo<G>, server_nonce: &PublicNonce, ) -> Result<(), &'static str>
Used by the server to verify if the partial signature in the bundle is valid
Sourcepub fn finish(
&self,
vtxo: &Vtxo<Full>,
server_pub_nonce: &PublicNonce,
server_sec_nonce: SecretNonce,
server_key: &Keypair,
) -> (Signature, Transaction, ServerVtxo<Full>)
pub fn finish( &self, vtxo: &Vtxo<Full>, server_pub_nonce: &PublicNonce, server_sec_nonce: SecretNonce, server_key: &Keypair, ) -> (Signature, Transaction, ServerVtxo<Full>)
Used by the server to finish the forfeit signature using its own nonce
NB users don’t need to know this signature