Types for using the Unified Mailbox feature of the bark server.
For more information on the mailbox, check the docs/mailbox.md file.
Structs
- Blinded
Mailbox Identifier - Blinded identifier for a mailbox
- Invalid
Mailbox Identifier - Mailbox
Authorization - Authorization to read a VTXO mailbox
- Mailbox
Blinding Error - The blinded mailbox point and the ECDH tweak sum to the point at infinity, which is not a valid curve point. This happens when the peer chose the blinded point equal to the ECDH-derived tweak, so treat it as an invalid peer input.
- Mailbox
Identifier - Identifier for a mailbox