Module mailbox

Module mailbox 

Types for using the Unified Mailbox feature of the bark server.

For more information on the mailbox, check the docs/mailbox.md file.

Structs

BlindedMailboxIdentifier
Blinded identifier for a mailbox
MailboxAuthorization
Authorization to read a VTXO mailbox
MailboxIdentifier
Identifier for a mailbox

Enums

MailboxType