Module offboard

Module offboard 

Offboard mechanism using connector-swaps

Connector VTXOs

Connector outputs are plain key-spend p2tr outputs for the server key, so the watchman can sweep their dust once they are no longer needed. We create internal “ServerVtxo“s for them. Because they must not be swept before they are no longer required (i.e. when the input VTXO expires) — spending a connector invalidates the forfeit tx it belongs to, forgoing the full input VTXO amount, not just the dust — we use the expiry height on the VTXO to indicate when they can be swept.

Structs

InvalidOffboardRequestError
InvalidOffboardTxError
InvalidUserPartialSignatureError
OffboardForfeitContext
OffboardForfeitResult
OffboardForfeitSignatures
OffboardRequest
Contains information regarding an offboard that a client would like to perform.

Enums

OffboardForfeitError
Something is wrong with what was handed to an OffboardForfeitContext.

Constants

OFFBOARD_TX_CONNECTOR_VOUT
The output index of the connector output in the offboard tx
OFFBOARD_TX_OFFBOARD_VOUT
The output index of the offboard output in the offboard tx