pub enum HashlockVersion {
V0,
V1,
}Expand description
The version of the hashlock clauses used in the leaves of a VTXO tree.
Trees created before the PROTOCOL_VERSION_HASHLOCK_CLAUSES protocol
version used the v0 unlock scripts.
We forgot to properly encode the difference in the trees, so version used is detected at runtime and then stored inside the tree.
Variants